package org.jeecg.modules.system.controller;

import cn.com.ctop.userefficientvideomap.entity.DesignMaterialInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.jeecg.modules.system.service.IPerformanceService2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 设计师季度绩效表
 *
 * @author jeecg-boot
 * @version V1.0
 * @date 2019-12-10
 */
@Slf4j
@Api(tags = "设计师季度绩效表")
@RestController
@RequestMapping("/ctop/performance2")
public class PerformanceController2 {
    @Autowired
    private IPerformanceService2 performanceService;

    //平台的总有效数量、素材总数、素材有效率、总跑量、当前可获得绩效
    @AutoLog(value = "平台的总有效数量、素材总数、素材有效率、总跑量、当前可获得绩效")
    @ApiOperation(value = "平台的总有效数量、素材总数、素材有效率、总跑量、当前可获得绩效", notes = "平台的总有效数量、素材总数、素材有效率、总跑量、当前可获得绩效")
    @PostMapping(value = "/getPerformanceInfo")
    public Map<String,Object> getPerformanceInfo() {
        Map<String,Object> resultMap = new HashMap<>();
        try {
            resultMap = performanceService.getPerformanceInfo();
        } catch (Exception e) {
            log.error(e.getMessage(), e);
        }
        return resultMap;
    }

    //有效率排行榜
    @AutoLog(value = "有效率排行榜")
    @ApiOperation(value = "有效率排行榜", notes = "有效率排行榜")
    @PostMapping(value = "/effiRateRank")
    public Map<String,Object> effiRateRank(@RequestParam(name = "pageSize")Integer pageSize) {
        Map<String,Object> resultMap = new HashMap<>();
        try {
            resultMap = performanceService.effiRateRank(pageSize);
        } catch (Exception e) {
            log.error(e.getMessage(), e);
        }
        return resultMap;
    }

    //素材、素材跑量、封面点击数、封面曝光数、行为数
    @AutoLog(value = "素材、素材跑量、封面点击数、封面曝光数、行为数")
    @ApiOperation(value = "素材、素材跑量、封面点击数、封面曝光数、行为数", notes = "素材、素材跑量、封面点击数、封面曝光数、行为数")
    @PostMapping(value = "/materialInfoList")
    public Map<String,Object> materialInfoList() {
        Map<String,Object> resultMap = new HashMap<>();
        try {
            List<DesignMaterialInfo> designMaterialInfoList= performanceService.materialInfoList();
            resultMap.put("designMaterialInfoList",designMaterialInfoList);
        } catch (Exception e) {
            log.error(e.getMessage(), e);
        }
        return resultMap;
    }

    //点击+符号 投放账户、投放账户、跑量
    @AutoLog(value = "点击账户增加_投放账户、投放账户、跑量")
    @ApiOperation(value = "点击账户增加_投放账户、投放账户、跑量", notes = "点击账户增加_投放账户、投放账户、跑量")
    @PostMapping(value = "/materialAccountInfo")
    public Map<String,Object> materialAccountInfo(@RequestParam(name = "materialId")String materialId) {
        Map<String,Object> resultMap = new HashMap<>();
        try {
            List<DesignMaterialInfo> designMaterialInfoList= performanceService.materialAccountInfo(materialId);
            resultMap.put("designMaterialInfoList",designMaterialInfoList);
        } catch (Exception e) {
            log.error(e.getMessage(), e);
        }
        return resultMap;
    }

   /*
    @AutoLog(value = "设计师季度绩效表-分页列表查询")
    @ApiOperation(value = "设计师季度绩效表-分页列表查询", notes = "设计师季度绩效表-分页列表查询")
    @GetMapping(value = "/list")
    public Result<IPage<Performance>> queryPageList(Performance performance,
                                                    @RequestParam(name = "pageNo", defaultValue = "1") Integer pageNo,
                                                    @RequestParam(name = "pageSize", defaultValue = "10") Integer pageSize,
                                                    HttpServletRequest req) {
        Result<IPage<Performance>> result = new Result<IPage<Performance>>();
        QueryWrapper<Performance> queryWrapper = QueryGenerator.initQueryWrapper(performance, req.getParameterMap());
        Page<Performance> page = new Page<Performance>(pageNo, pageSize);
        IPage<Performance> pageList = performanceService.page(page, queryWrapper);
        result.setSuccess(true);
        result.setResult(pageList);
        return result;
    }


    @AutoLog(value = "设计师季度绩效表-添加")
    @ApiOperation(value = "设计师季度绩效表-添加", notes = "设计师季度绩效表-添加")
    @PostMapping(value = "/add")
    public Result<Performance> add(@RequestBody Performance performance) {
        Result<Performance> result = new Result<Performance>();
        try {
            performanceService.save(performance);
            result.success("添加成功！");
        } catch (Exception e) {
            log.error(e.getMessage(), e);
            result.error500("操作失败");
        }
        return result;
    }


    @AutoLog(value = "设计师季度绩效表-编辑")
    @ApiOperation(value = "设计师季度绩效表-编辑", notes = "设计师季度绩效表-编辑")
    @PutMapping(value = "/edit")
    public Result<Performance> edit(@RequestBody Performance performance) {
        Result<Performance> result = new Result<Performance>();
        Performance performanceEntity = performanceService.getById(performance.getId());
        if (performanceEntity == null) {
            result.error500("未找到对应实体");
        } else {
            boolean ok = performanceService.updateById(performance);
            if (ok) {
                result.success("修改成功!");
            }
        }

        return result;
    }


    @AutoLog(value = "设计师季度绩效表-通过id删除")
    @ApiOperation(value = "设计师季度绩效表-通过id删除", notes = "设计师季度绩效表-通过id删除")
    @DeleteMapping(value = "/delete")
    public Result<?> delete(@RequestParam(name = "id", required = true) String id) {
        try {
            performanceService.removeById(id);
        } catch (Exception e) {
            log.error("删除失败", e.getMessage());
            return Result.error("删除失败!");
        }
        return Result.ok("删除成功!");
    }


    @AutoLog(value = "设计师季度绩效表-批量删除")
    @ApiOperation(value = "设计师季度绩效表-批量删除", notes = "设计师季度绩效表-批量删除")
    @DeleteMapping(value = "/deleteBatch")
    public Result<Performance> deleteBatch(@RequestParam(name = "ids", required = true) String ids) {
        Result<Performance> result = new Result<Performance>();
        if (ids == null || "".equals(ids.trim())) {
            result.error500("参数不识别！");
        } else {
            this.performanceService.removeByIds(Arrays.asList(ids.split(",")));
            result.success("删除成功!");
        }
        return result;
    }


    @AutoLog(value = "设计师季度绩效表-通过id查询")
    @ApiOperation(value = "设计师季度绩效表-通过id查询", notes = "设计师季度绩效表-通过id查询")
    @GetMapping(value = "/queryById")
    public Result<Performance> queryById(@RequestParam(name = "id", required = true) String id) {
        Result<Performance> result = new Result<Performance>();
        Performance performance = performanceService.getById(id);
        if (performance == null) {
            result.error500("未找到对应实体");
        } else {
            result.setResult(performance);
            result.setSuccess(true);
        }
        return result;
    }

    @GetMapping("/project/list")
    public Map<String, Object> projectList(@RequestParam(name = "pageNo", defaultValue = "1") Integer pageNo,
                                           @RequestParam(name = "pageSize", defaultValue = "10") Integer pageSize) {
        return performanceService.getUserOptimizerProjectList(pageNo, pageSize);
    }

    @GetMapping("/account/list")
    public Map<String, Object> accountList(@RequestParam(name = "pageNo", defaultValue = "1") Integer pageNo,
                                           @RequestParam(name = "pageSize", defaultValue = "10") Integer pageSize, Long projectId) {
        return performanceService.getUserOptimizerAccountList(projectId, pageNo, pageSize);
    }*/
}
